@@ -45,6 +45,9 @@ read_dir <- function(path, verbose = T, print_fun = NULL, maximization = TRUE,
 #'  These formats are specified in more detail in our github wiki.
 #' @param subsampling Logical. Whether *.cdat files are subsampled?
 #' @param print_fun Function used to print output when in verbose mode
+#' @param full_aggregation If True, individual DataSets are aggregated as much as possible: all DataSets
+#' with the same algorithmname, function id and dimension are combined together. This leads to information loss
+#' related to static variables, so only use if that information is not required. 
 #'
 #' @return A DataSetList object
 #' @export
@@ -52,7 +55,7 @@ read_dir <- function(path, verbose = T, print_fun = NULL, maximization = TRUE,
 #' path <- system.file("extdata", "ONE_PLUS_LAMDA_EA", package = "IOHanalyzer")
 #' DataSetList(path)
 DataSetList <- function(path = NULL, verbose = T, print_fun = NULL, maximization = NULL,
-                        format = IOHprofiler, subsampling = FALSE) {
+                        format = IOHprofiler, subsampling = FALSE, full_aggregation = TRUE) {
   if (is.null(path))
     return(structure(list(), class = c('DataSetList', 'list')))
   
@@ -164,13 +167,18 @@ DataSetList <- function(path = NULL, verbose = T, print_fun = NULL, maximization
   
   attr(object, 'suite') <- suite
   attr(object, 'maximization') <- maximization
-  clean_DataSetList(object)
+  attr(object, 'ID') <- attr(object, 'algId')
+  attr(object, 'ID_attributes') <- c('algId')
+  if (full_aggregation)
+    clean_DataSetList(object)
+  else
+    object
 }
 
 
 #' Clean DataSetList object by concatenating DataSets
 #' 
-#' Concatenates all DataSets with the same algorith name, function id and dimension
+#' Concatenates all DataSets with the same ID, algid, function id and dimension
 #'  
 #' @param dsList The DataSetList object to clean
 #' @export
@@ -179,11 +187,17 @@ DataSetList <- function(path = NULL, verbose = T, print_fun = NULL, maximization
 clean_DataSetList <- function(dsList) {
   #To ensure no uninitialized variables are present
   .I <- NULL
+  
+  if (is.null(attr(dsList, 'ID'))) {
+    dsList <- change_id(dsList, getOption("IOHanalyzer.ID_vars", c("algId")))
+  }
+  
   cases <- mapply(
     function(...) paste0(list(...), collapse = ','),
     attr(dsList, 'funcId'), 
     attr(dsList, 'DIM'),
     attr(dsList, 'algId'),
+    attr(dsList, 'ID'),
     SIMPLIFY = T,
     USE.NAMES = F
   )
@@ -203,6 +217,7 @@ clean_DataSetList <- function(dsList) {
     attr(dsList, 'DIM') <- sapply(dsList, function(ds) attr(ds, 'DIM'))
     attr(dsList, 'funcId') <- sapply(dsList, function(ds) attr(ds, 'funcId'))
     attr(dsList, 'algId') <- sapply(dsList, function(ds) attr(ds, 'algId'))
+    attr(dsList, 'ID') <- sapply(dsList, function(ds) attr(ds, 'ID'))
   }
   dsList
 }
@@ -227,7 +242,7 @@ c.DataSetList <- function(...) {
   if (!any((class(object)) == 'DataSetList'))
     class(object) <- c('DataSetList', class(object))
 
-  for (attr_str in c('DIM', 'funcId', 'algId')) {
+  for (attr_str in c('DIM', 'funcId', 'algId', 'ID')) {
     attr(object, attr_str) <- unlist(lapply(dsl, function(x) attr(x, attr_str)))
   }
 
@@ -239,7 +254,7 @@ c.DataSetList <- function(...) {
   )
   
   # These attributes NEED to be the same across the datasetlist
-  for (attr_str in c('maximization')) {
+  for (attr_str in c('maximization', 'ID_attributes')) {
     temp <- unique(
         unlist(lapply(dsl, function(x) attr(x, attr_str)))
     )
@@ -270,6 +285,7 @@ c.DataSetList <- function(...) {
 
   # also slice the attributes accordingly
   attr(obj, 'DIM') <- attr(x, 'DIM')[i]
+  attr(obj, 'ID') <- attr(x, 'ID')[i]
   attr(obj, 'funcId') <- attr(x, 'funcId')[i]
   attr(obj, 'algId') <- attr(x, 'algId')[i]
   attr(obj, 'suite') <- attr(x, 'suite')
@@ -329,7 +345,7 @@ summary.DataSetList <- function(object, ...) {
             suite = attr(d, 'suite'),
             funcId = attr(d, 'funcId'),
             DIM = attr(d, 'DIM'),
-            algId = attr(d, 'algId'),
+            ID = attr(d, 'ID'),
             datafile = attr(d, 'datafile'),
             comment = attr(d, 'comment')
           )
@@ -371,7 +387,7 @@ arrange.DataSetList <- function(dsl, ...) {
     }
 
     v <- as.character(v)
-    if (v %in% c('DIM', 'funcId', 'algId'))
+    if (v %in% c('DIM', 'funcId', 'ID'))
       cols[[i]] <- v
     else {
       cols[[i]] <- NULL
@@ -390,7 +406,7 @@ arrange.DataSetList <- function(dsl, ...) {
   dsl <- dsl[idx]
 
   # TODO: perhaps we do not need those attributes at all...
-  for (v in c('DIM', 'funcId', 'algId'))
+  for (v in c('DIM', 'funcId', 'ID'))
     attr(dsl, v) <- sapply(dsl, function(d) attr(d, v))
   dsl
 }
@@ -414,13 +430,8 @@ get_ERT.DataSetList <- function(ds, ftarget, budget = NULL, algorithm = 'all', .
   }
 
 #' @rdname get_RT_summary
-#' @param algorithm DEPRECATED, will be removed in next release. Which algorithms in the DataSetList to consider. 
 #' @export
-get_RT_summary.DataSetList <- function(ds, ftarget, budget = NULL, algorithm = 'all', ...) {
-    if (!missing("algorithm")) warning("Argument 'algorithm' is deprecated and will be removed in the next release of IOHanalyzer.")
-    if (algorithm != 'all')
-      ds <- subset(ds, algId == algorithm)
-    
+get_RT_summary.DataSetList <- function(ds, ftarget, budget = NULL, ...) {
     rbindlist(lapply(ds, function(ds) {
       res <-
         cbind(attr(ds, 'DIM'),
@@ -583,6 +594,18 @@ get_PAR_sample.DataSetList <- function(ds, idxValue, algorithm = 'all', ...) {
   rbindlist(lapply(ds, function(ds) get_PAR_sample(ds, idxValue, ...)), fill = T)
 }
 
+#' @rdname get_id
+#' @export
+get_id.DataSetList <- function(ds, ...) {
+  temp <- attr(ds, 'ID')
+  if (is.null(temp)) {
+    warning("No ID attribute set, returning the algId's instead. (from 1.6.0 onwards, ID attributes are always added
+            to new datasets, see the 'change_id' function.")
+    return(get_algId(ds))
+  }
+  return(unique(temp))
+}
+
 #' Get all dimensions present in a DataSetList
 #'
 #' @param dsList The DataSetLsit
@@ -619,6 +642,18 @@ get_funcId <- function(dsList) {
   sort(lli)
 }
 
+#' Get all function names present in a DataSetList
+#'
+#' @param dsList The DataSetLsit
+#'
+#' @return A list of all unique function names which occur in the DataSetList
+#' @export
+#' @examples
+#' get_funcName(dsl)
+get_funcName <- function(dsList) {
+  unique(unname(unlist(sapply(dsList, function(d) attr(d, 'funcName')))))
+}
+
 #' Get all algorithm ids present in a DataSetList
 #'
 #' @param dsList The DataSetLsit
@@ -700,48 +735,165 @@ get_runtimes <- function(dsList) {
   ))))
 }
 
-# #' Get the best function value reached in a DataSetList
-# #'
-# #' @param dsList The DataSetLsit
-# #'
-# #' @return A list matrices of all runtime values which occur in the DataSetList
-# #' @export
-# get_best_targets <- function(dsList, by = 'funcId', maximize = T) {
-#   targets <- c()
-#   funcIds <- get_funcId(dsList)
+#' Get all attributes which can be used to subset a DataSetList
+#'
+#' @param dsl The DataSetList
+#'
+#' @return The list of available attributes
+#' @export
+#' @examples
+#' get_static_attributes(dsl)
+get_static_attributes <- function(dsl) {
+  full_names <- unique(unlist(lapply(dsl, function(ds) {names(attributes(ds))})))
+  
+  reserved_attributes <- c("names", "class", "suite", "maximization", "algInfo", "comment", 
+                           "datafile", "maxRT", "finalFV", "format")
+  setdiff(full_names, reserved_attributes)
+}
 
-#   for (i in seq_along(aggr_attr)) {
-#     data <- subset(dsList, funcId == funcIds[i])
+#' Get all options for a specific attribute which can be used to subset a DataSetList
+#' 
+#' This is a more generic version of the existing `get_dim`, `get_funcId` and `get_algId` functions.
+#' Note the only attributes returned by `get_static_attributes` are supported in this funcion
+#'
+#' @param dsl The DataSetList
+#' @param attribute the name of the attribute for which to get the available options in dsl
+#' @return The list of options for the specified attribute
+#' @export
+#' @examples
+#' get_static_attribute_values(dsl, 'funcId')
+get_static_attribute_values <- function(dsl, attribute) {
+  unique(unlist(lapply(dsl, function(ds) {attr(ds, attribute)})))
+}
 
-#     Fall <- get_funvals(data)
-#     Fval <- ifelse(maximize, max(Fall), min(Fall))
-#     targets <- c(targets, Fval)
-#   }
-#   targets
-# }
-
-# TODO: the attribute list should als be sliced here...
 #' Filter a DataSetList by some criteria
 #'
-#' @param x The DataSetLsit
-#' @param ... The condition to filter on. Can be any expression which assigns True or False
-#' to a DataSet object, such as DIM == 625 or funcId == 2
+#' @param x The DataSetList
+#' @param ... The conditions to filter on. Can be any expression which assigns True or False
+#' to a DataSet object, such as DIM == 625 or funcId == 2. Usage of && and || is only supported on default attributes 
+#' (funcId, algId, DIM), not on combinations of with other attributes (e.g. instance). In those cases, & and | should 
+#' be used respectively. Alternatively, this can be used as a keyword argument named 'text', with the condition as a 
+#' string to be parsed. This allows exectution of subset commands on arbitrary variables in code. 
 #'
 #' @return The filtered DataSetList
 #' @export
 #' @examples
 #' subset(dsl, funcId == 1)
+#' subset(dsl, funcId == 1 && DIM == 16) # Can use && and || for default attributes
+#' subset(dsl, instance == 1)
+#' subset(dsl, instance == 1 & funcId == 1) # Can use & and | for all attributes
+#' subset(dsl, instance == 1, funcId == 1) # Comma-seperated conditions are treated as AND
 subset.DataSetList <- function(x, ...) {
-  condition_call <- substitute(list(...))
   enclos <- parent.frame()
-  idx <- sapply(x,
-                function(ds)
-                  all(unlist(
-                    eval(condition_call, attributes(ds), enclos)
-                  )))
-  x[idx]
+  if (hasArg('text')) {
+    text <- list(...)$text
+    condition_call <- parse(text = text)
+  } else {
+    condition_call <- substitute(list(...))
+    condition_call <- condition_call[2:length(condition_call)]
+  }
+  
+  obj <- lapply(x,
+                function(ds){
+                  mask <- tryCatch(expr = {
+                    mask <- NULL
+                    for (idx in seq(length(condition_call))) {
+                      mask_temp <- unlist(
+                        eval(condition_call[[idx]], attributes(ds), enclos = enclos)
+                      )
+                      if (is.null(mask)) mask <- mask_temp
+                      else {
+                        if (length(mask_temp) == 1 && !mask_temp) {
+                          mask <- F
+                        } else if (length(mask_temp) == 1) {
+                          mask <- mask
+                        } else if (length(mask_temp) == length(mask) || length(mask) == 1) {
+                          mask <- mask & mask_temp
+                        } else {
+                          stop("Error creating mask")
+                        }
+                        
+                      }
+                    }
+                    mask
+                  }, error = function(e) {F})
+                  
+                  if (length(mask) == 1 && mask) return(ds)
+                  else if (length(mask) == 1 || !any(mask)) return(NULL)
+                  return(subset(ds, mask))
+                })
+  
+  class(obj) <- c('DataSetList', class(obj))
+  obj <- Filter(Negate(is.null), obj)
+  
+  # also slice the attributes accordingly
+  attr(obj, 'suite') <- attr(x, 'suite')
+  attr(obj, 'maximization') <- attr(x, 'maximization')
+  attr(obj, 'DIM') <- sapply(obj, function(ds) attr(ds, 'DIM'))
+  attr(obj, 'funcId') <- sapply(obj, function(ds) attr(ds, 'funcId'))
+  attr(obj, 'algId') <- sapply(obj, function(ds) attr(ds, 'algId'))
+  unique_ids <- unlist(sapply(obj, function(ds) attr(ds, 'unique_id')))
+  if (!any(is.null(unique_ids))) {
+    attr(obj, 'unique_ids') <- unique_ids
+  }
+  return(obj)
 }
 
+#' Add unique identifiers to each DataSet in the provided DataSetList based on static attributes
+#' 
+#' Note that this function returns a new DataSetList object, since a split into new datasetlist has to be done to
+#' ensure each dataset has exactly one unique identifier.
+#' Note that only static attributes (see `get_static_attributes`) can be used to create unique identifiers. 
+#'
+#' @param dsl The DataSetList
+#' @param attrs The list of attributes to combine into a unique identifier
+#' @return A new DataSetList object where the split has been done based on the provided attributes, and the unique
+#' identifier has been added. 
+#' @export
+#' @examples
+#' change_id(dsl, c('instance'))
+change_id <- function(dsl, attrs) {
+  if (length(dsl) == 0) return(dsl)
+  if (!all(attrs %in% get_static_attributes(dsl))) stop("Selected attributes are not usable to create unique ids")
+  grid <- expand.grid(lapply(attrs, function(x){get_static_attribute_values(dsl, x)}))
+  colnames(grid) <- attrs
+  
+  dsl_new <- DataSetList()
+  attr_vals <- c()
+  for (x in transpose(grid)) {
+    #TODO: on Windows, UTF-8 Characters get converted into <U+XXXX> characters, which then 
+    #don't interact correctly with the parse used in 'subset' function, leading to empty datasetlist objects.
+    #I'm not aware of any way to fix this, so UFT-8 characters should be avoided in ID for now.
+    conditions <- paste0(unlist(lapply(seq(length(attrs)), function(idx) {
+      paste0(attrs[[idx]], ' == "', x[[idx]], '"')
+    })), collapse = " & ")
+    dsl_temp <- subset(dsl, text = conditions)
+    if (length(attrs) == 1) 
+      attr_val <- x
+    else
+      attr_val <- paste0(x, collapse = "_")
+    
+    attr_vals <- c(attr_vals, rep(attr_val, length(dsl_temp)))
+    dsl_new <- c(dsl_new, dsl_temp)
+  }
+  attr(dsl_new, 'ID_attributes') <- attrs
+  attr(dsl_new, 'ID') <- attr_vals
+  for (idx in seq(length(dsl_new))) {
+    attr(dsl_new[[idx]], 'ID') <- attr_vals[[idx]]
+  }
+  class(dsl_new) <- c("DataSetList", "list")
+  attr(dsl_new, 'suite') <- attr(dsl, 'suite')
+  attr(dsl_new, 'maximization') <- attr(dsl, 'maximization')
+  
+  attr(dsl_new, 'DIM') <- lapply(dsl_new, function(x) attr(x, 'DIM'))
+  attr(dsl_new, 'funcId') <- lapply(dsl_new, function(x) attr(x, 'funcId'))
+  attr(dsl_new, 'algId') <- lapply(dsl_new, function(x) attr(x, 'algId'))
+  dsl_new
+}
+
+
+
+
 #' Save DataTable in multiple formats
 #' 
 #' @param df The DataTable to store
@@ -825,7 +977,8 @@ get_ECDF_targets <- function(dsList, type = "log-linear", number_targets = 10) {
 #' @examples 
 #' generate_data.Single_Function(subset(dsl, funcId == 1), which = 'by_RT')
 generate_data.Single_Function <- function(dsList, start = NULL, stop = NULL, 
-                                          scale_log = F, which = 'by_RT', include_opts = F, budget = NULL) {
+                                          scale_log = F, which = 'by_RT', 
+                                          include_opts = F, budget = NULL) {
   
   if (length(get_funcId(dsList)) != 1 || length(get_dim(dsList)) != 1 ) {
     #Required because target generation is included in this function, 
@@ -851,11 +1004,11 @@ generate_data.Single_Function <- function(dsList, start = NULL, stop = NULL,
     Xseq <- seq_FV(all, start, stop, length.out = 60,
                    scale = ifelse(scale_log, 'log', 'linear'))
     if (include_opts) {
-      for (algid in get_algId(dsList)) {
+      for (uid in get_id(dsList)) {
         if (maximization)
-          Xseq <- c(Xseq, max(get_funvals(subset(dsList, algId == algid))))
+          Xseq <- c(Xseq, max(get_funvals(subset(dsList, ID == uid))))
         else
-          Xseq <- c(Xseq, min(get_funvals(subset(dsList, algId == algid))))
+          Xseq <- c(Xseq, min(get_funvals(subset(dsList, ID == uid))))
       }
       Xseq <- unique(sort(Xseq))
     }
@@ -865,8 +1018,8 @@ generate_data.Single_Function <- function(dsList, start = NULL, stop = NULL,
     Xseq <- seq_RT(all, start, stop, length.out = 60,
                    scale = ifelse(scale_log, 'log', 'linear'))
     if (include_opts) {
-      for (algid in get_algId(dsList)) {
-        Xseq <- c(Xseq, max(get_funvals(subset(dsList, algId == algid))))
+      for (uid in get_id(dsList)) {
+        Xseq <- c(Xseq, max(get_funvals(subset(dsList, ID == uid))))
       }
       Xseq <- unique(sort(Xseq))
     }
@@ -933,7 +1086,7 @@ generate_data.hist <- function(dsList, target, use.equal.bins = F, which = 'by_R
       lapply(
         dsList, 
         function(ds) {
-          algId <- attr(ds, 'algId')
+          ID <- get_id(ds)
           
           if (which == 'by_RT') 
             data <- get_RT_sample(ds, target, output = 'long')$RT
@@ -961,7 +1114,7 @@ generate_data.hist <- function(dsList, target, use.equal.bins = F, which = 'by_R
           plot_data <- data.frame(
             x = res$mids, 
             y = res$counts, 
-            algId = algId,
+            ID = ID,
             width = breaks[2] - breaks[1],
             text =  plot_text
           )
@@ -1024,7 +1177,7 @@ generate_data.ECDF <- function(dsList, targets, scale_log = F, which = 'by_RT',
   }
   
   dt <- as.data.table(rbindlist(lapply(dsList, function(df) {
-    algId <- attr(df, 'algId')
+    ID <- get_id(df)
     if (by_rt) {
       temp <- targets[DIM == attr(df, 'DIM'), c('target', 'funcId')]
       targets_ <- temp[funcId == attr(df, 'funcId')][['target']]
@@ -1047,9 +1200,9 @@ generate_data.ECDF <- function(dsList, targets, scale_log = F, which = 'by_RT',
     data.frame(x = x,
                mean = apply(m, 2, . %>% mean(na.rm = T)),
                sd = apply(m, 2, . %>% sd(na.rm = T))) %>%
-      mutate(upper = mean + sd, lower = mean - sd, algId = algId)
+      mutate(upper = mean + sd, lower = mean - sd, ID = ID)
   })))
-  dt[, mean(mean), by = .(x, algId)][, .(mean = V1, algId = algId, x = x)]
+  dt[, mean(mean), by = .(x, ID)][, .(mean = V1, ID = ID, x = x)]
 }
 
 
@@ -1079,17 +1232,17 @@ generate_data.AUC <- function(dsList, targets, scale_log = F, which = 'by_RT', d
     dt_ecdf <- generate_data.ECDF(dsList, targets, scale_log, which)
   }
   max_idx <- nrow(unique(dt_ecdf[,'x']))
-  dt_ecdf[, idx := seq(max_idx), by = 'algId']
+  dt_ecdf[, idx := seq(max_idx), by = 'ID']
   dt3 = copy(dt_ecdf)
   dt3[, idx := idx - 1]
-  dt_merged = merge(dt_ecdf, dt3, by = c('algId', 'idx'))
-  colnames(dt_merged) <- c("algId", "idx", "mean_pre", "x_pre", "mean_post", "x")
+  dt_merged = merge(dt_ecdf, dt3, by = c('ID', 'idx'))
+  colnames(dt_merged) <- c("ID", "idx", "mean_pre", "x_pre", "mean_post", "x")
   dt_merged[, auc_contrib := ((mean_pre + mean_post)/2)*(x - x_pre)]
-  dt_merged[, auc := cumsum(auc_contrib)/x, by = 'algId']
+  dt_merged[, auc := cumsum(auc_contrib)/x, by = 'ID']
   #TODO: just for max x
   if (multiple_x)
-    return(dt_merged[, c('algId','x','auc') ])
-  return(dt_merged[idx == (max_idx - 1), c('algId','x','auc') ])
+    return(dt_merged[, c('ID','x','auc') ])
+  return(dt_merged[idx == (max_idx - 1), c('ID','x','auc') ])
 }
   
   
@@ -1210,7 +1363,7 @@ generate_data.Aggr <- function(dsList, aggr_on = 'funcId', targets = NULL, which
   }
  
   aggr_attr <- if (aggr_on == 'funcId') get_funcId(dsList) else get_dim(dsList)
-  N <- length(get_algId(dsList))
+  N <- length(get_id(dsList))
 
   dt <- rbindlist(lapply(aggr_attr, function(agg_val) {
     if (by_rt) {
@@ -1218,7 +1371,7 @@ generate_data.Aggr <- function(dsList, aggr_on = 'funcId', targets = NULL, which
         dt <- get_RT_summary(subset(dsList, funcId == agg_val), targets[funcId == agg_val][['target']])
       else
         dt <- get_RT_summary(subset(dsList, DIM == agg_val), targets[DIM == agg_val][['target']])
-      dt[, c('algId', value = 'ERT', 'funcId', 'DIM')]
+      dt[, c('ID', value = 'ERT', 'funcId', 'DIM')]
       setnames(dt, 'ERT', 'value')
     }
     else{
@@ -1226,7 +1379,7 @@ generate_data.Aggr <- function(dsList, aggr_on = 'funcId', targets = NULL, which
         dt <- get_FV_summary(subset(dsList, funcId == agg_val), targets[funcId == agg_val][['target']])
       else
         dt <- get_FV_summary(subset(dsList, DIM == agg_val), targets[DIM == agg_val][['target']])
-      dt[, c('algId', value = 'mean', 'funcId', 'DIM')]
+      dt[, c('ID', value = 'mean', 'funcId', 'DIM')]
       setnames(dt, 'mean', 'value')
     }
   }))
@@ -1273,7 +1426,7 @@ generate_data.ECDF_raw <- function(dsList, targets, scale_log = F) {
   }
   
   dt <- as.data.table(rbindlist(lapply(dsList, function(df) {
-    algId <- attr(df, 'algId')
+    ID <- get_id(df)
     temp <- targets[DIM == attr(df, 'DIM'), c('target', 'funcId')]
     targets_ <- temp[funcId == attr(df, 'funcId')][['target']]
     
@@ -1285,7 +1438,7 @@ generate_data.ECDF_raw <- function(dsList, targets, scale_log = F) {
         fun <- ecdf(data)
         hit <- if (is.function(fun)) fun(x) else NA
       }
-      data.table(hit = hit, rt = x, target = target, funcId = attr(df, 'funcId'), DIM = attr(df, 'DIM'), algId = attr(df, 'algId'))
+      data.table(hit = hit, rt = x, target = target, funcId = attr(df, 'funcId'), DIM = attr(df, 'DIM'), ID = ID)
     }) %>%
       do.call(rbind, .)
     m
