@@ -13,7 +13,7 @@ rt_stats_box <- function(width = 12, collapsible = T, collapsed = T) {
         checkboxInput('RTSummary.Statistics.Single', label = HTML('<p>\\(f_{\\text{min}} = f_{\\text{max}}\\)?
                                                            Once toggled, only \\(f_{\\text{min}}\\) is
                                                            used to generate the table on the right.</p>'), value = FALSE),
-        selectInput('RTSummary.Statistics.Algid', 'Algorithms', choices = NULL, selected = NULL),
+        selectInput('RTSummary.Statistics.ID', 'Select which IDs to include:', choices = NULL, selected = NULL, multiple = T),
         hr(),
         selectInput('RTSummary.Statistics.Format', 'Format', choices = supported_table_format, selected = supported_table_format[[1]]),
         downloadButton("RTSummary.Statistics.Download", "Save this table")
@@ -47,8 +47,8 @@ rt_sample_box <- function(width = 12, collapsible = T, collapsed = T) {
         # TODO: do we need this log scaling?
         # checkboxInput('F_LOGSPACE_DATA_SUMMARY',
         #               label = HTML('Evenly space target values in \\(log_{10}\\) space')),
-        selectInput('RTSummary.Sample.Algid', 'Algorithms',
-                    choices = NULL, selected = NULL),
+        selectInput('RTSummary.Sample.ID', 'Select which IDs to include:',
+                    choices = NULL, selected = NULL, multiple = T),
 
         hr(),
         selectInput('RTSummary.Sample.DownloadFormat', 'Format of the table',
@@ -76,9 +76,7 @@ rt_overview_box <- function(width = 12, collapsible = T, collapsed = T) {
       collapsible = collapsible, collapsed = collapsed,
       sidebarPanel(
         width = 3,
-        HTML('<p align="justify">Select which algorithms to show.</p>'),
-
-        selectInput('RTSummary.Overview.Algid', 'Algorithms', choices = NULL, selected = NULL),
+        selectInput('RTSummary.Overview.ID', 'Select which IDs to include:', choices = NULL, selected = NULL, multiple = T),
         hr(),
         selectInput('RTSummary.Overview.Format', 'File-format', choices = supported_table_format, selected = supported_table_format[[1]]),
         downloadButton("RTSummary.Overview.Download", "Save this table")
