@@ -59,6 +59,11 @@ general_settings_box <- function(width=12, collapsible = T, collapsed = F) {
           numericInput("Settings.General.Precision", label = "Function value precision (digits)",
                        value = 2),
           hr(),
+          HTML_P("ID variables"),
+          selectInput("Settings.ID.Variables", label = "Attributes used to create IDs",
+                      multiple = T, selected = NULL, choices = NULL),
+          checkboxInput("Settings.Use_Funcname", "Use function names instead of IDs"),
+          hr(),
           downloadButton("Settings.Download", "Download current general settings file"),
           fileInput("Settings.Upload", "Upload a settings file", accept = "rds")
         ),
